"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _ = require("lodash");
var child_process = require("child_process");
var os = require("os");
var util = require("util");
var nodeify_ts_1 = require("nodeify-ts");
var exec = child_process.exec;
var cleanJson = function (line) {
    var parts, re, str, m, value, value2, comma;
    if (line.indexOf('ISODate') > -1) {
        parts = line.split(':');
        re = /ISODate\("(.*)"/g;
        str = line;
        while ((m = re.exec(str)) !== null) {
            if (m.index === re.lastIndex) {
                re.lastIndex++;
            }
            value = m && m[1] ? m[1] : 'error';
        }
        return util.format('%s : { "$date" : "%s" },', parts[0], value);
    }
    else if (line.indexOf('ObjectId') > -1) {
        parts = line.split(':');
        re = /ObjectId\("(.*)"/g;
        str = line;
        while ((m = re.exec(str)) !== null) {
            if (m.index === re.lastIndex) {
                re.lastIndex++;
            }
            value = m && m[1] ? m[1] : 'error';
        }
        return util.format('%s : { "$oid" : "%s" },', parts[0], value);
    }
    else if (line.indexOf('NumberLong') > -1) {
        parts = line.split(':');
        re = /NumberLong\((.*)\)(,*)/g;
        str = line;
        while ((m = re.exec(str)) !== null) {
            if (m.index === re.lastIndex) {
                re.lastIndex++;
            }
            value = m && m[1] ? m[1] : 'error';
            comma = m && m[2] ? m[2] : '';
        }
        return util.format('%s : { "$numberLong" : "%s" }%s', parts[0], value, comma);
    }
    else if (line.indexOf('Timestamp') > -1) {
        parts = line.split(':');
        re = /Timestamp\((\d*),\s*(\d*)\)/g;
        str = line;
        while ((m = re.exec(str)) !== null) {
            if (m.index === re.lastIndex) {
                re.lastIndex++;
            }
            value = m && m[1] ? m[1] : 'error';
            value2 = m && m[2] ? m[2] : 'error';
        }
        return util.format('%s : { "$timestamp" : { "t" : %s, "i" : %s } },', parts[0], value, value2);
    }
    else {
        return line;
    }
};
var objectStartingRow = function (resultp) {
    var lines = resultp.raw.split(os.EOL);
    resultp.lines = _.clone(lines);
    var jsonStartIndex = 0;
    for (var i = 0; i < lines.length; i++) {
        var line = lines[i];
        if (line === '{') {
            jsonStartIndex = i;
            break;
        }
    }
    try {
        var tempArray = lines.splice(jsonStartIndex);
        var jsonString = tempArray.reduce(function (previousValue, currentValue) {
            var cleaned = cleanJson(currentValue.trim());
            return previousValue + cleaned;
        }, '');
        resultp.object = JSON.parse(jsonString);
    }
    catch (e) {
        resultp.error = e;
    }
    return resultp;
};
var extractResult = function (result) {
    var extracterArray = [
        {
            re: /"db.isMaster/,
            run: function (resultp) {
                return objectStartingRow(resultp);
            },
        },
        {
            re: /"rs.conf/,
            run: function (resultp) {
                return objectStartingRow(resultp);
            },
        },
        {
            re: /"rs.initiate/,
            run: function (resultp) {
                return objectStartingRow(resultp);
            },
        },
        {
            re: /"rs.add/,
            run: function (resultp) {
                return objectStartingRow(resultp);
            },
        },
        {
            re: /"rs.status/,
            run: function (resultp) {
                return objectStartingRow(resultp);
            },
        },
    ];
    extracterArray.forEach(function (extracter) {
        var re = extracter.re;
        var str = result.command;
        var m;
        if ((m = re.exec(str)) !== null) {
            if (m.index === re.lastIndex) {
                re.lastIndex++;
            }
            return extracter.run(result);
        }
    });
    return result;
};
var Mongo = (function () {
    function Mongo(options) {
        if (options === void 0) { options = new Options(); }
        this.options = options;
    }
    Mongo.prototype.command = function (command, callback) {
        var mongo = this;
        var execCommand = 'mongo ';
        var promise = Promise.resolve().then(function () {
            var params = mongo.options.toParams();
            execCommand += " " + params + " --eval \"" + command + "\" ";
            var execOptions = {
                cwd: mongo.options.currentWorkingDirectory,
                env: {
                    DEBUG: '',
                    EDITOR: process.env.EDITOR,
                    HOME: process.env.HOME,
                    HOMEDRIVE: process.env.HOMEDRIVE,
                    HOMEPATH: process.env.HOMEPATH,
                    PATH: process.env.PATH,
                },
                maxBuffer: 200 * 1024 * 1024,
            };
            return new Promise(function (resolve, reject) {
                exec(execCommand, execOptions, function (error, stdout, stderr) {
                    if (error) {
                        var message = "error: '" + error + "' stdout = '" + stdout + "' stderr = '" + stderr + "'";
                        console.error(message);
                        reject(message);
                    }
                    resolve({ stderr: stderr, stdout: stdout });
                });
            });
        }).then(function (data) {
            var result = {
                command: execCommand,
                error: data.stderr,
                raw: data.stdout,
            };
            return extractResult(result);
        });
        return nodeify_ts_1.default(promise, callback);
    };
    return Mongo;
}());
exports.Mongo = Mongo;
var Options = (function () {
    function Options(currentWorkingDirectory, host, port) {
        if (host === void 0) { host = 'localhost'; }
        if (port === void 0) { port = '27017'; }
        this.currentWorkingDirectory = currentWorkingDirectory;
        this.host = host;
        this.port = port;
    }
    Options.prototype.toParams = function () {
        var _this = this;
        var params = Object.keys(this).reduce(function (previousValue, key) {
            if (key === 'currentWorkingDirectory') {
                return previousValue;
            }
            var value = _this[key];
            return previousValue + " --" + key + " " + value;
        }, '');
        return params;
    };
    return Options;
}());
exports.Options = Options;
//# sourceMappingURL=index.js.map